@@ -4,7 +4,7 @@ import numpy as np
 import scipy.interpolate as scintr 
 import pandas as pd
 
-phdat = pd.read_csv('HaThOr/higgins_ph/pHint_optimal.csv')
+phdat = pd.read_csv('higgins_ph/pHint_optimal.csv')
 
 
 # Let us assume:
